<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author  Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */

use fid\FormModel\AddressValidator;
use Zend\Filter\StringTrim;
use Zend\InputFilter\CollectionInputFilter;
use Zend\Validator\Callback;
use Zend\Validator\NotEmpty;
use Zend\Validator\StringLength;

return [
    'name' => 'addresses',
    'type'         => CollectionInputFilter::class,
    'input_filter' => [
        'line1'   => [
            'name'       => 'line1',
            'filters'    => [
                StringTrim::class => [
                    'name' => StringTrim::class,
                ],
            ],
            'validators' => [
                NotEmpty::class     => [
                    'name'    => NotEmpty::class,
                    'options' => [
                        'type' => NotEmpty::NULL,
                    ],
                ],
                Callback::class     => [
                    'name'    => Callback::class,
                    'options' => [
                        'callback' => AddressValidator::class
                            . '::validate',
                        'messages' => [
                            Callback::INVALID_VALUE => 'error_empty_address_value',
                        ],
                    ],
                ],
                StringLength::class => [
                    'name'    => StringLength::class,
                    'options' => [
                        'max' => 255
                    ]
                ],
            ],
        ],
        'line2'   => [
            'name'       => 'line2',
            'required' => false,
            'filters'    => [
                StringTrim::class => [
                    'name' => StringTrim::class,
                ],
            ],
            'validators' => [
                StringLength::class => [
                    'name'    => StringLength::class,
                    'options' => [
                        'max' => 255
                    ]
                ],
            ],
        ],
        'zip'     => [
            'name'       => 'zip',
            'filters'    => [
                StringTrim::class => [
                    'name' => StringTrim::class,
                ],
            ],
            'validators' => [
                NotEmpty::class     => [
                    'name'    => NotEmpty::class,
                    'options' => [
                        'type' => NotEmpty::NULL,
                    ],
                ],
                Callback::class     => [
                    'name'    => Callback::class,
                    'options' => [
                        'callback' => AddressValidator::class
                            . '::validate',
                        'messages' => [
                            Callback::INVALID_VALUE => 'error_empty_address_value',
                        ],
                    ],
                ],
                StringLength::class => [
                    'name'    => StringLength::class,
                    'options' => [
                        'max' => 255
                    ]
                ],
            ],
        ],
        'city'    => [
            'name'       => 'city',
            'filters'    => [
                StringTrim::class => [
                    'name' => StringTrim::class,
                ],
            ],
            'validators' => [
                NotEmpty::class     => [
                    'name'    => NotEmpty::class,
                    'options' => [
                        'type' => NotEmpty::NULL,
                    ],
                ],
                Callback::class     => [
                    'name'    => Callback::class,
                    'options' => [
                        'callback' => AddressValidator::class
                            . '::validate',
                        'messages' => [
                            Callback::INVALID_VALUE => 'error_empty_address_value',
                        ],
                    ],
                ],
                StringLength::class => [
                    'name'    => StringLength::class,
                    'options' => [
                        'max' => 255
                    ]
                ],
            ],
        ],
        'country' => [
            'name'       => 'country',
            'filters'    => [
                StringTrim::class => [
                    'name' => StringTrim::class,
                ],
            ],
            'validators' => [
                NotEmpty::class     => [
                    'name'    => NotEmpty::class,
                    'options' => [
                        'type' => NotEmpty::NULL,
                    ],
                ],
                Callback::class     => [
                    'name'    => Callback::class,
                    'options' => [
                        'callback' => AddressValidator::class
                            . '::validate',
                        'messages' => [
                            Callback::INVALID_VALUE => 'error_empty_address_value',
                        ],
                    ],
                ],
                StringLength::class => [
                    'name'    => StringLength::class,
                    'options' => [
                        'max' => 255
                    ]
                ],
            ],
        ],
    ],
];
